==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/bg/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Етикет за статус не съществува.',
    'assoc_assets'	 => 'Този етикет за статус е свързан с най-малко един актив и не може да бъде изтрит. Моля актуализирайте вашите активи да не се прехвърлят към този статус и опитайте отново.',


    'create' => array(
        'error'   => 'Етикет за статус не беше създаден, моля опитайте отново.',
        'success' => 'Етикет за статус създаден успешно.'
    ),

    'update' => array(
        'error'   => 'Етикет за статус не беше актуализиран, моля опитайте отново.',
        'success' => 'Етикет за статус актуализиран успешно.'
    ),

    'delete' => array(
        'confirm'   => 'Сигурни ли сте, че желаете да изтриете този етикет за статус?',
        'error'   => 'Имаше проблем при изтриването на етикета за статус. Моля опитайте отново.',
        'success' => 'Етикета за статус бе изтрит успешно.'
    ),

    'help' => array(
        'undeployable'   => 'Тези активи не могат да бъдат възлагани на никого.',
        'deployable'   => 'Тези активи могат да бъдат проверени. След като бъдат присвоени, те ще поемат мета статус на <i class="fa fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Тези активи не могат да бъдат отметнати и ще се показват само в архивирания изглед. Това е полезно за запазване на информация за активи за бюджетиране / исторически цели, но задържането им извън ежедневния списък на активите.',
        'pending'   => 'Тези активи все още не могат да бъдат прехвърляни на никого, често използвани за артикули, които са предназначени за ремонт, но се очаква да се върнат в обръщение.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/bg/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Етикет за статус не съществува.',
    'assoc_assets'	 => 'Този етикет за статус е свързан с най-малко един актив и не може да бъде изтрит. Моля актуализирайте вашите активи да не се прехвърлят към този статус и опитайте отново.',

    'create' => [
        'error'   => 'Етикет за статус не беше създаден, моля опитайте отново.',
        'success' => 'Етикет за статус създаден успешно.',
    ],

    'update' => [
        'error'   => 'Етикет за статус не беше актуализиран, моля опитайте отново.',
        'success' => 'Етикет за статус актуализиран успешно.',
    ],

    'delete' => [
        'confirm'   => 'Сигурни ли сте, че желаете да изтриете този етикет за статус?',
        'error'   => 'Имаше проблем при изтриването на етикета за статус. Моля опитайте отново.',
        'success' => 'Етикета за статус бе изтрит успешно.',
    ],

    'help' => [
        'undeployable'   => 'Тези активи не могат да бъдат възлагани на никого.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Тези активи не могат да бъдат отметнати и ще се показват само в архивирания изглед. Това е полезно за запазване на информация за активи за бюджетиране / исторически цели, но задържането им извън ежедневния списък на активите.',
        'pending'   => 'Тези активи все още не могат да бъдат прехвърляни на никого, често използвани за артикули, които са предназначени за ремонт, но се очаква да се върнат в обръщение.',
    ],

];
